/* geo_config.h.  Generated from geo_config.h.in by configure.  */
/* geo_config.h.in.  Generated from configure.ac by autoheader.  */

/* Define if you have the <strings.h> header file. */
#define GEOTIFF_HAVE_STRINGS_H 1

/* Disable WGS84 parameters */
/* #undef GEO_NORMALIZE_DISABLE_TOWGS84 */

/* Define to 1 if you have the <dlfcn.h> header file. */
#define HAVE_DLFCN_H 1

/* Define to 1 if you have the <inttypes.h> header file. */
#define HAVE_INTTYPES_H 1

/* Define to 1 if you have the 'm' library (-lm). */
#define HAVE_LIBM 1

/* Define to 1 if you have the <locale.h> header file. */
#define HAVE_LOCALE_H 1

/* Define to 1 if you have the <proj.h> header file. */
#define HAVE_PROJ_H 1

/* Define to 1 if you have the <stdint.h> header file. */
#define HAVE_STDINT_H 1

/* Define to 1 if you have the <stdio.h> header file. */
#define HAVE_STDIO_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H 1

/* Define to 1 if you have the <strings.h> header file. */
#define HAVE_STRINGS_H 1

/* Define to 1 if you have the <string.h> header file. */
#define HAVE_STRING_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define to 1 if you have the <unistd.h> header file. */
#define HAVE_UNISTD_H 1

/* Define to 1 if you have the <zlib.h> header file. */
#define HAVE_ZLIB_H 1

/* Define to the sub-directory where libtool stores uninstalled libraries. */
#define LT_OBJDIR ".libs/"

/* Name of package */
#define PACKAGE "libgeotiff"

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "warmerdam@pobox.com"

/* Define to the full name of this package. */
#define PACKAGE_NAME "libgeotiff"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING "libgeotiff 1.7.4"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "libgeotiff"

/* Define to the home page for this package. */
#define PACKAGE_URL ""

/* Define to the version of this package. */
#define PACKAGE_VERSION "1.7.4"

/* Define to 1 if all of the C89 standard headers exist (not just the ones
   required in a freestanding environment). This macro is provided for
   backward compatibility; new code need not use it. */
#define STDC_HEADERS 1

/* Version number of package */
#define VERSION "1.7.4"
